==> v10.3.1.tar.gz: barker/barker/barker/routers/table.py <==
import uuid

from datetime import timedelta

import barker.schemas.table as schemas

from fastapi import APIRouter, Depends, HTTPException, Security, status
from sqlalchemy import select, update
from sqlalchemy.exc import SQLAlchemyError

from ..core.config import settings
from ..core.security import get_current_active_user as get_user
from ..db.session import SessionFuture
from ..models.food_table import FoodTable
from ..models.overview import Overview
from ..schemas.user_token import UserToken


router = APIRouter()


@router.post("/list", response_model=list[schemas.Table])
def sort_order(
    data: list[schemas.Table],
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> list[schemas.Table]:
    try:
        with SessionFuture() as db:
            for index, item in enumerate(data):
                db.execute(update(FoodTable).where(FoodTable.id == item.id_).values(sort_order=index))
            db.commit()
            return [
                schemas.Table(
                    id=item.id,
                    name=item.name,
                    seats=item.seats,
                    section=schemas.SectionLink(id=item.section_id, name=item.section.name),
                    isActive=item.is_active,
                    sortOrder=item.sort_order,
                )
                for item in db.execute(select(FoodTable).order_by(FoodTable.sort_order)).scalars().all()
            ]
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.post("", response_model=schemas.Table)
def save(
    data: schemas.TableIn,
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> schemas.Table:
    try:
        with SessionFuture() as db:
            item = FoodTable(
                name=data.name,
                seats=data.seats,
                section_id=data.section.id_,
                is_active=data.is_active,
            )
            db.add(item)
            db.commit()
            return food_table_info(item)
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.put("/{id_}", response_model=schemas.Table)
def update_route(
    id_: uuid.UUID,
    data: schemas.TableIn,
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> schemas.Table:
    try:
        with SessionFuture() as db:
            item: FoodTable = db.execute(select(FoodTable).where(FoodTable.id == id_)).scalar_one()
            item.name = data.name
            item.seats = data.seats
            item.section_id = data.section.id_
            item.is_active = data.is_active
            db.commit()
            return food_table_info(item)
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.delete("/{id_}", response_model=schemas.TableBlank)
def delete_route(
    id_: uuid.UUID,
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> schemas.TableBlank:
    try:
        with SessionFuture() as db:
            item: FoodTable = db.execute(select(FoodTable).where(FoodTable.id == id_)).scalar_one()
            db.delete(item)
            db.commit()
            return food_table_blank()
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.get("", response_model=schemas.TableBlank)
def show_blank(
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> schemas.TableBlank:
    return food_table_blank()


@router.get("/list", response_model=list[schemas.Table])
def show_list(user: UserToken = Depends(get_user)):
    with SessionFuture() as db:
        return [
            food_table_info(item)
            for item in db.execute(select(FoodTable).order_by(FoodTable.sort_order)).scalars().all()
        ]


@router.get("/running")
def show_running(user: UserToken = Depends(get_user)):
    with SessionFuture() as db:
        list_ = (
            db.execute(
                select(FoodTable).where(FoodTable.is_active == True).order_by(FoodTable.sort_order)  # noqa: E712
            )
            .scalars()
            .all()
        )

        food_tables = []
        for item in list_:
            ft = {
                "id": item.id,
                "name": item.name,
                "seats": item.seats,
                "section": {"id": item.section_id, "name": item.section.name},
                "isActive": item.is_active,
                "sortOrder": item.sort_order,
            }
            if item.status is not None:
                ft["status"] = item.status.status
                ft["voucherId"] = item.status.voucher_id
                ft["pax"] = item.status.voucher.pax
                ft["date"] = (item.status.voucher.date + timedelta(minutes=settings.TIMEZONE_OFFSET_MINUTES)).strftime(
                    "%d-%b-%Y %H:%M"
                )
                ft["amount"] = round(item.status.voucher.amount, 0)
                if item.status.guest is not None:
                    ft["guest"] = item.status.guest.customer.name
                    ft["bold"] = item.status.guest.customer.print_in_bill
            food_tables.append(ft)
        return food_tables


@router.get("/from-voucher/{id_}", response_model=schemas.Table | schemas.TableBlank)
def show_voucher(
    id_: uuid.UUID,
    user: UserToken = Security(get_user),
) -> schemas.Table | schemas.TableBlank:
    with SessionFuture() as db:
        overview: Overview = db.execute(select(Overview).where(Overview.voucher_id == id_)).scalars().one_or_none()
        if overview is not None:
            return food_table_info(overview.food_table)
        return food_table_blank()


@router.get("/{id_}", response_model=schemas.Table)
def show_id(
    id_: uuid.UUID,
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> schemas.Table:
    with SessionFuture() as db:
        item: FoodTable = db.execute(select(FoodTable).where(FoodTable.id == id_)).scalar_one()
        return food_table_info(item)


def food_table_info(item: FoodTable) -> schemas.Table:
    return schemas.Table(
        id=item.id,
        name=item.name,
        seats=item.seats,
        section=schemas.SectionLink(id=item.section_id, name=item.section.name),
        isActive=item.is_active,
        status="" if item.status is None else item.status.status,
        sortOrder=item.sort_order,
        voucherId=None if item.status is None else item.status.voucher_id,
    )


def food_table_blank() -> schemas.TableBlank:
    return schemas.TableBlank(name="", seats=0, isActive=True, sortOrder=0)

==> v11.2.0.tar.gz: barker/barker/barker/routers/table.py <==
import uuid

from datetime import timedelta

import barker.schemas.table as schemas

from fastapi import APIRouter, Depends, HTTPException, Security, status
from sqlalchemy import select, update
from sqlalchemy.exc import SQLAlchemyError

from ..core.config import settings
from ..core.security import get_current_active_user as get_user
from ..db.session import SessionFuture
from ..models.food_table import FoodTable
from ..models.overview import Overview
from ..schemas.user_token import UserToken


router = APIRouter()


@router.post("/list", response_model=list[schemas.Table])
def sort_order(
    data: list[schemas.Table],
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> list[schemas.Table]:
    try:
        with SessionFuture() as db:
            for index, item in enumerate(data):
                db.execute(update(FoodTable).where(FoodTable.id == item.id_).values(sort_order=index))
            db.commit()
            return [
                schemas.Table(
                    id=item.id,
                    name=item.name,
                    seats=item.seats,
                    section=schemas.SectionLink(id=item.section_id, name=item.section.name),
                    isActive=item.is_active,
                    sortOrder=item.sort_order,
                )
                for item in db.execute(select(FoodTable).order_by(FoodTable.sort_order)).scalars().all()
            ]
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.post("", response_model=schemas.Table)
def save(
    data: schemas.TableIn,
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> schemas.Table:
    try:
        with SessionFuture() as db:
            item = FoodTable(
                name=data.name,
                seats=data.seats,
                section_id=data.section.id_,
                is_active=data.is_active,
            )
            db.add(item)
            db.commit()
            return food_table_info(item)
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.put("/{id_}", response_model=schemas.Table)
def update_route(
    id_: uuid.UUID,
    data: schemas.TableIn,
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> schemas.Table:
    try:
        with SessionFuture() as db:
            item: FoodTable = db.execute(select(FoodTable).where(FoodTable.id == id_)).scalar_one()
            item.name = data.name
            item.seats = data.seats
            item.section_id = data.section.id_
            item.is_active = data.is_active
            db.commit()
            return food_table_info(item)
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.delete("/{id_}", response_model=schemas.TableBlank)
def delete_route(
    id_: uuid.UUID,
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> schemas.TableBlank:
    try:
        with SessionFuture() as db:
            item: FoodTable = db.execute(select(FoodTable).where(FoodTable.id == id_)).scalar_one()
            db.delete(item)
            db.commit()
            return food_table_blank()
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.get("", response_model=schemas.TableBlank)
def show_blank(
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> schemas.TableBlank:
    return food_table_blank()


@router.get("/list", response_model=list[schemas.Table])
def show_list(user: UserToken = Depends(get_user)):
    with SessionFuture() as db:
        return [
            food_table_info(item)
            for item in db.execute(select(FoodTable).order_by(FoodTable.sort_order)).scalars().all()
        ]


@router.get("/running")
def show_running(user: UserToken = Depends(get_user)):
    with SessionFuture() as db:
        list_ = (
            db.execute(
                select(FoodTable).where(FoodTable.is_active == True).order_by(FoodTable.sort_order)  # noqa: E712
            )
            .scalars()
            .all()
        )

        food_tables = []
        for item in list_:
            ft = {
                "id": item.id,
                "name": item.name,
                "seats": item.seats,
                "section": {"id": item.section_id, "name": item.section.name},
                "isActive": item.is_active,
                "sortOrder": item.sort_order,
            }
            if item.status is not None:
                ft["status"] = item.status.status
                ft["voucherId"] = item.status.voucher_id
                ft["pax"] = item.status.voucher.pax
                ft["date"] = (item.status.voucher.date + timedelta(minutes=settings.TIMEZONE_OFFSET_MINUTES)).strftime(
                    "%d-%b-%Y %H:%M"
                )
                ft["amount"] = round(item.status.voucher.amount, 0)
                if item.status.guest is not None:
                    ft["guest"] = item.status.guest.customer.name
                    ft["bold"] = item.status.guest.customer.print_in_bill
            food_tables.append(ft)
        return food_tables


@router.get("/from-voucher/{id_}", response_model=schemas.Table | schemas.TableBlank)
def show_voucher(
    id_: uuid.UUID,
    user: UserToken = Security(get_user),
) -> schemas.Table | schemas.TableBlank:
    with SessionFuture() as db:
        overview = db.execute(select(Overview).where(Overview.voucher_id == id_)).scalars().one_or_none()
        if overview is not None:
            return food_table_info(overview.food_table)
        return food_table_blank()


@router.get("/{id_}", response_model=schemas.Table)
def show_id(
    id_: uuid.UUID,
    user: UserToken = Security(get_user, scopes=["sections"]),
) -> schemas.Table:
    with SessionFuture() as db:
        item: FoodTable = db.execute(select(FoodTable).where(FoodTable.id == id_)).scalar_one()
        return food_table_info(item)


def food_table_info(item: FoodTable) -> schemas.Table:
    return schemas.Table(
        id=item.id,
        name=item.name,
        seats=item.seats,
        section=schemas.SectionLink(id=item.section_id, name=item.section.name),
        isActive=item.is_active,
        status="" if item.status is None else item.status.status,
        sortOrder=item.sort_order,
        voucherId=None if item.status is None else item.status.voucher_id,
    )


def food_table_blank() -> schemas.TableBlank:
    return schemas.TableBlank(name="", seats=0, isActive=True, sortOrder=0)
